Index: /trunk/src/VBox/ValidationKit/testdriver/txsclient.py
===================================================================
--- /trunk/src/VBox/ValidationKit/testdriver/txsclient.py	(revision 84658)
+++ /trunk/src/VBox/ValidationKit/testdriver/txsclient.py	(revision 84659)
@@ -280,5 +280,5 @@
             abMsg.append(0);
 
-        reporter.log2('sendMsgInt: op=%s len=%d to=%d' % (sOpcode, len(abMsg), cMsTimeout));
+        reporter.log2('sendMsgInt: op=%s len=%d timeout=%d' % (sOpcode, len(abMsg), cMsTimeout));
         return self.sendBytes(abMsg, cMsTimeout);
 
@@ -643,5 +643,5 @@
         rc = self.waitForTask(self.cMsTimeout + 5000);
         if rc is False:
-            reporter.maybeErr(self.fErr, 'asyncToSync: waitForTask failed...');
+            reporter.maybeErr(self.fErr, 'asyncToSync: waitForTask (timeout %d) failed...' % (self.cMsTimeout,));
             self.cancelTask();
             #reporter.log2('asyncToSync(%s): returns False (#2)' % (fnAsync, rc));
@@ -1635,5 +1635,5 @@
         Returns timeout in milliseconds.
         """
-        return 30000 + cbFile / 256; # 256 KiB/s (picked out of thin air)
+        return 30000 + cbFile / 32; # 32 KiB/s (picked out of thin air)
 
     @staticmethod
